@@ -14,13 +14,13 @@
 #' @seealso <https://nflreadr.nflverse.com/articles/dictionary_player_stats.html>
 "dictionary_player_stats"
 
-#' Data Dictionary: Player Stats Defense
+#' Data Dictionary: Team Stats
 #'
-#' A dataframe containing the data dictionary for [`load_player_stats()`]
+#' A dataframe containing the data dictionary for [`load_team_stats()`]
 #'
-#' @seealso `vignette("Data Dictionary - Player Stats Defense")`
-#' @seealso <https://nflreadr.nflverse.com/articles/dictionary_player_stats_def.html>
-"dictionary_player_stats_def"
+#' @seealso `vignette("Data Dictionary - Team Stats")`
+#' @seealso <https://nflreadr.nflverse.com/articles/dictionary_team_stats.html>
+"dictionary_team_stats"
 
 #' Data Dictionary: Fantasy Player IDs
 #'
@@ -206,3 +206,22 @@
 #'   \item{value attribute}{The "correct" name.}
 #' }
 "team_abbr_mapping_norelocate"
+
+#' nflverse Timezone
+#'
+#' A character string defining the default timezone for data across the nflverse
+#'
+"nflverse_data_timezone"
+
+#' dictionary_roster_status
+#'
+#' A dictionary translating the shorthand roster status to more verbose explanations of what each status indicates.
+"dictionary_roster_status"
+
+#' Data Dictionary: Players
+#'
+#' A dataframe containing the data dictionary for [`load_players()`]
+#'
+#' @seealso `vignette("Data Dictionary - Players")`
+#' @seealso <https://nflreadr.nflverse.com/articles/dictionary_players.html>
+"dictionary_players"
