@@ -20,9 +20,14 @@
 #' @seealso [`dictionary_combine`] for the data dictionary as bundled within the package
 #'
 #' @export
-load_combine <- function(seasons = TRUE, file_type = getOption("nflreadr.prefer", default = "rds")){
+load_combine <- function(
+  seasons = TRUE,
+  file_type = getOption("nflreadr.prefer", default = "rds")
+) {
   file_type <- rlang::arg_match0(file_type, c("rds", "csv", "parquet", "qs"))
-  url <- glue::glue("https://github.com/nflverse/nflverse-data/releases/download/combine/combine.{file_type}")
+  url <- glue::glue(
+    "https://github.com/nflverse/nflverse-data/releases/download/combine/combine.{file_type}"
+  )
   out <- load_from_url(url, seasons = seasons, nflverse = TRUE)
   return(out)
 }
