@@ -21,10 +21,14 @@
 #' @seealso Issues with this data should be filed here: <https://github.com/nflverse/nflverse-data>
 #'
 #' @export
-load_draft_picks <- function(seasons = TRUE,
-                             file_type = getOption("nflreadr.prefer", default = "rds")){
+load_draft_picks <- function(
+  seasons = TRUE,
+  file_type = getOption("nflreadr.prefer", default = "rds")
+) {
   file_type <- rlang::arg_match0(file_type, c("rds", "csv", "parquet", "qs"))
-  url <- glue::glue("https://github.com/nflverse/nflverse-data/releases/download/draft_picks/draft_picks.{file_type}")
+  url <- glue::glue(
+    "https://github.com/nflverse/nflverse-data/releases/download/draft_picks/draft_picks.{file_type}"
+  )
   out <- load_from_url(url, seasons = seasons, nflverse = TRUE)
   return(out)
 }
