@@ -19,17 +19,22 @@
 #' @seealso Issues with this data should be filed here: <https://github.com/nflverse/nflreadr> and it will be triaged appropriately.
 #'
 #' @export
-load_officials <- function(seasons = TRUE,
-                           file_type = getOption("nflreadr.prefer", default = "rds")){
+load_officials <- function(
+  seasons = TRUE,
+  file_type = getOption("nflreadr.prefer", default = "rds")
+) {
   file_type <- rlang::arg_match0(file_type, c("rds", "csv", "parquet", "qs"))
-  url <- glue::glue("https://github.com/nflverse/nflverse-data/releases/download/officials/officials.{file_type}")
+  url <- glue::glue(
+    "https://github.com/nflverse/nflverse-data/releases/download/officials/officials.{file_type}"
+  )
 
-  if(!isTRUE(seasons)) {
+  if (!isTRUE(seasons)) {
     stopifnot(
       is.numeric(seasons),
       all(seasons >= 2015),
       all(seasons <= nflreadr::most_recent_season())
-    )}
+    )
+  }
 
   out <- load_from_url(url, seasons = seasons, nflverse = TRUE)
   return(out)
