@@ -17,13 +17,15 @@
 #' @seealso Issues with this data should be filed here: <https://github.com/nflverse/nflverse-pbp>
 #'
 #' @export
-load_teams <- function(current = TRUE){
-  out <- load_from_url("https://github.com/nflverse/nflverse-pbp/raw/master/teams_colors_logos.rds",
-                       nflverse = TRUE,
-                       nflverse_type = "team graphics")
+load_teams <- function(current = TRUE) {
+  out <- load_from_url(
+    "https://github.com/nflverse/nflverse-pbp/raw/master/teams_colors_logos.rds",
+    nflverse = TRUE,
+    nflverse_type = "team graphics"
+  )
 
-  if (isTRUE(current)){
-    out <- out[out$team_abbr %in% nflreadr::team_abbr_mapping,]
+  if (isTRUE(current)) {
+    out <- out[out$team_abbr %in% nflreadr::team_abbr_mapping, ]
   }
   out
 }
