@@ -5,12 +5,14 @@
 #'
 #' @export
 #' @keywords internal
-.for_cran <- function(){
-
+.for_cran <- function() {
   cores <- min(
     getOption("Ncpus", default = 2L),
-    as.integer(Sys.getenv("OMP_THREAD_LIMIT",unset = "2")),
-    floor(as.integer(Sys.getenv("_R_CHECK_EXAMPLE_TIMING_CPU_TO_ELAPSED_THRESHOLD_", unset = 2))),
+    as.integer(Sys.getenv("OMP_THREAD_LIMIT", unset = "2")),
+    floor(as.integer(Sys.getenv(
+      "_R_CHECK_EXAMPLE_TIMING_CPU_TO_ELAPSED_THRESHOLD_",
+      unset = 2
+    ))),
     2L,
     na.rm = TRUE
   )
