@@ -8,12 +8,12 @@ use_dt <- FALSE
 if(requireNamespace("DT", quietly = TRUE)) use_dt <- TRUE
 
 ## ----eval = use_dt------------------------------------------------------------
-DT::datatable(nflreadr::dictionary_schedules,
-              options = list(scrollX = TRUE, pageLength = 25),
-              filter = "top",
-              rownames = FALSE
-              )
+# DT::datatable(nflreadr::dictionary_schedules,
+#               options = list(scrollX = TRUE, pageLength = 25),
+#               filter = "top",
+#               rownames = FALSE
+#               )
 
 ## ----eval = !use_dt-----------------------------------------------------------
-#  knitr::kable(nflreadr::dictionary_schedules)
+knitr::kable(nflreadr::dictionary_schedules)
 
