@@ -1,5 +1,4 @@
 test_that("load_ff_rankings", {
-
   skip_if_offline("github.com")
   skip_on_cran()
 
@@ -11,7 +10,6 @@ test_that("load_ff_rankings", {
 })
 
 test_that("load_ff_rankings", {
-
   skip_if_offline("github.com")
   skip_on_cran()
 
@@ -25,12 +23,15 @@ test_that("load_ff_rankings", {
 })
 
 test_that("load_ff_opportunity", {
-
   skip_if_offline("github.com")
   skip_on_cran()
 
   ff_opps_week <- load_ff_opportunity(seasons = TRUE)
-  ff_opps_pbp <- load_ff_opportunity(seasons = 2021, stat_type = "pbp_pass", model_version = "v1.0.0")
+  ff_opps_pbp <- load_ff_opportunity(
+    seasons = 2021,
+    stat_type = "pbp_pass",
+    model_version = "v1.0.0"
+  )
 
   expect_s3_class(ff_opps_week, "tbl_df")
   expect_gt(nrow(ff_opps_week), 80000)
